@@ -69,6 +69,15 @@ const HeWizardStorage = ({collapsibleSections, deploymentType, errorMsg, errorMs
                     </div>
                 </div>
 
+                {glusterSelected &&
+                    <div className="row">
+                        <div className="alert alert-info col-sm-8" style={{marginLeft: "20px"}}>
+                            <span className="pficon pficon-info" />
+                            <strong>{messages.GLUSTER_REPLICA}</strong>
+                        </div>
+                    </div>
+                }
+
                 <div className="form-group">
                     <label className="col-md-3 control-label">Storage Type</label>
                     <div className="col-md-6">
@@ -277,6 +286,7 @@ const HeWizardStorage = ({collapsibleSections, deploymentType, errorMsg, errorMs
                         <label className="col-md-3 control-label">Mount Options</label>
                         <div className="col-md-6">
                             <input type="text" style={{width: "250px"}}
+                                   placeholder="option1=value1,option2=value2"
                                    title=""
                                    className="form-control"
                                    value={storageConfig.mntOptions.value}
